<template>
    <div class="eve-content">
        <div class="eve-header">
            <div class="header-item" style="width: 8%">序号</div>
            <div
                class="header-item"
                :style="{width: it.width}"
                v-for="(it, ind) in listOption"
                :key="ind"
            >
                {{ it.label }}
            </div>
            <div class="header-item" style="width: 12%">操作</div>
        </div>
        <div class="eve-body" v-if="dataList.length && dataList.length > 7">
            <vue-seamless-scroll :data="dataList" :class-option="defaultOption">
                <div
                    class="body-item"
                    v-for="(item, index) in dataList"
                    :key="index"
                >
                    <div class="item-row" style="width: 8%">
                        {{ index + 1 }}
                    </div>
                    <div
                        class="item-row"
                        :style="{width: it.width}"
                        v-for="(it, ind) in listOption"
                        :key="ind"
                    >
                        <span
                            v-if="it.dict"
                            :title="getDictName(it.dict, item[it.prop])"
                            >{{ getDictName(it.dict, item[it.prop]) }}</span
                        >

                        <span v-else :title="item[it.prop]">{{
                            item[it.prop]
                        }}</span>
                    </div>
                    <div class="item-row" style="width: 12%">
                        <span class="operate" @click="goSystem(item)">研判</span>
                    </div>
                </div>
            </vue-seamless-scroll>
        </div>
        <div class="eve-body" v-else-if="dataList.length && dataList.length <= 7">
                <div
                    class="body-item"
                    v-for="(item, index) in dataList"
                    :key="index"
                >
                    <div class="item-row" style="width: 8%">
                        {{ index + 1 }}
                    </div>
                    <div
                        class="item-row"
                        :style="{width: it.width}"
                        v-for="(it, ind) in listOption"
                        :key="ind"
                    >
                        <span
                            v-if="it.dict"
                            :title="getDictName(it.dict, item[it.prop])"
                            >{{ getDictName(it.dict, item[it.prop]) }}</span
                        >

                        <span v-else :title="item[it.prop]">{{
                            item[it.prop]
                        }}</span>
                    </div>
                    <div class="item-row" style="width: 12%">
                        <span class="operate" @click="goSystem(item)">研判</span>
                    </div>
                </div>
        </div>
        <el-empty
            v-else
            description="暂无数据"
            :image-size="100"
            :image="require('@/assets/img/empty1.png')"
        ></el-empty>
    </div>
</template>

<script>
import bigScreenAPI from '@/api/BigScreen/index.js'
import vueSeamlessScroll from 'vue-seamless-scroll'
import utils from '@/utils.js'
export default {
    name: 'todayEvent',
    components: {vueSeamlessScroll},
    props: {
        areaCode: {
            type: String,
            default: '',
        },
    },
    watch: {
        areaCode: {
            handler(newValue, oldValue) {
                this.queryForm.querys[0].value = newValue
                this.getData()
            },
        },
    },
    computed: {
        defaultOption() {
            return {
                step: 0.12, // 数值越大速度滚动越快
                limitMoveNum: 2, // 开始无缝滚动的数据量 this.dataList.length
                hoverStop: true, // 是否开启鼠标悬停stop
                direction: 1, // 0向下 1向上 2向左 3向右
                openWatch: true, // 开启数据实时监控刷新dom
                singleHeight: 0, // 单步运动停止的高度(默认值0是无缝不停止的滚动) direction => 0/1
                singleWidth: 0, // 单步运动停止的宽度(默认值0是无缝不停止的滚动) direction => 2/3
                waitTime: 1000, // 单步运动停止的时间(默认值1000ms)
            }
        },
    },
    data() {
        return {
            queryForm: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'area_full_code_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
            listOption: [
                {
                    label: '事件编号',
                    prop: 'eventCode',
                    width: '25%',
                },
                // {
                //     label: '事件名称',
                //     prop: 'eventName',
                //     width: '15%',
                // },
                {
                    label: '事件类型',
                    prop: 'eventType',
                    dict: 'sjfx-sjfl',
                    width: '15%',
                },
                {
                    label: '发生地点',
                    prop: 'address',
                    width: '40%',
                },
                // {
                //     label: '发生时间',
                //     prop: 'eventProduceTime',
                //     width: '15%',
                // },
            ],
            dataList: [], // 列表数据
        }
    },
    created() {
        this.queryForm.querys[0].value = this.areaCode
        this.getData()
    },
    methods: {
        // 获取今日事件数据列表
        getData() {
            bigScreenAPI.getEventAllView(this.queryForm).then((res) => {
                this.dataList = res.rows
            })
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        goSystem(item) {
            this.$emit('eventConfirmation', item,'今日事件')
        },
    },
}
</script>

<style scoped lang="scss">
.eve-content {
    height: calc(100% - 40px);
    .eve-header {
        display: flex;
        align-items: center;
        height: 26px;
        .header-item {
            text-align: center;
            color: #00eaff;
            font-size: 16px;
        }
    }
    .eve-body {
        height: calc(100% - 26px);
        overflow-y: hidden;
        .body-item {
            display: flex;
            align-items: center;
            height: 30px;
            .item-row {
                text-align: center;
                white-space: nowrap;
                overflow: hidden;
                text-overflow: ellipsis;
                font-size: 16px;
                color: rgba(255,255,255,0.7);
                span {
                    font-size: 16px;
                }
                .operate {
                    display: inline-block;
                    padding: 3px 4px;
                    background-color: #41a0ff;
                    transform: scale(0.8);
                    border-radius: 3px;
                    cursor: pointer;
                }
            }
        }
        &::-webkit-scrollbar {
            width: 0px !important;
        }
    }
}
</style>
